summaryrefslogtreecommitdiffstats
path: root/src/document/io
diff options
context:
space:
mode:
Diffstat (limited to 'src/document/io')
-rw-r--r--src/document/io/CsoundExporter.cpp4
-rw-r--r--src/document/io/CsoundExporter.h2
-rw-r--r--src/document/io/HydrogenLoader.cpp4
-rw-r--r--src/document/io/HydrogenLoader.h2
-rw-r--r--src/document/io/HydrogenXMLHandler.cpp6
-rw-r--r--src/document/io/HydrogenXMLHandler.h2
-rw-r--r--src/document/io/LilyPondExporter.cpp86
-rw-r--r--src/document/io/LilyPondExporter.h6
-rw-r--r--src/document/io/MupExporter.cpp4
-rw-r--r--src/document/io/MupExporter.h2
-rw-r--r--src/document/io/MusicXmlExporter.cpp4
-rw-r--r--src/document/io/MusicXmlExporter.h2
-rw-r--r--src/document/io/RG21Loader.cpp30
-rw-r--r--src/document/io/RG21Loader.h4
14 files changed, 79 insertions, 79 deletions
diff --git a/src/document/io/CsoundExporter.cpp b/src/document/io/CsoundExporter.cpp
index 70f1e51..9316de6 100644
--- a/src/document/io/CsoundExporter.cpp
+++ b/src/document/io/CsoundExporter.cpp
@@ -40,10 +40,10 @@
namespace Rosegarden
{
-CsoundExporter::CsoundExporter(TQObject *parent,
+CsoundExporter::CsoundExporter(TQObject *tqparent,
Composition *composition,
std::string fileName) :
- ProgressReporter(parent, "csoundExporter"),
+ ProgressReporter(tqparent, "csoundExporter"),
m_composition(composition),
m_fileName(fileName)
{
diff --git a/src/document/io/CsoundExporter.h b/src/document/io/CsoundExporter.h
index f179fb6..a2476e0 100644
--- a/src/document/io/CsoundExporter.h
+++ b/src/document/io/CsoundExporter.h
@@ -46,7 +46,7 @@ class Composition;
class CsoundExporter : public ProgressReporter
{
public:
- CsoundExporter(TQObject *parent, Composition *, std::string fileName);
+ CsoundExporter(TQObject *tqparent, Composition *, std::string fileName);
~CsoundExporter();
bool write();
diff --git a/src/document/io/HydrogenLoader.cpp b/src/document/io/HydrogenLoader.cpp
index 984527d..4a4876c 100644
--- a/src/document/io/HydrogenLoader.cpp
+++ b/src/document/io/HydrogenLoader.cpp
@@ -41,8 +41,8 @@ namespace Rosegarden
{
HydrogenLoader::HydrogenLoader(Studio *studio,
- TQObject *parent, const char *name):
- ProgressReporter(parent, name),
+ TQObject *tqparent, const char *name):
+ ProgressReporter(tqparent, name),
m_studio(studio)
{}
diff --git a/src/document/io/HydrogenLoader.h b/src/document/io/HydrogenLoader.h
index bd3cffb..e4975ad 100644
--- a/src/document/io/HydrogenLoader.h
+++ b/src/document/io/HydrogenLoader.h
@@ -54,7 +54,7 @@ class HydrogenLoader : public ProgressReporter
{
public:
HydrogenLoader(Studio *,
- TQObject *parent = 0, const char *name = 0);
+ TQObject *tqparent = 0, const char *name = 0);
/**
* Load and parse the Hydrogen file \a fileName, and write it into the
diff --git a/src/document/io/HydrogenXMLHandler.cpp b/src/document/io/HydrogenXMLHandler.cpp
index 9854648..565fe6d 100644
--- a/src/document/io/HydrogenXMLHandler.cpp
+++ b/src/document/io/HydrogenXMLHandler.cpp
@@ -272,9 +272,9 @@ HydrogenXMLHandler::endElement(const TQString& /*namespaceURI*/,
// whole bar unit segment.
//
m_segment->setEndMarkerTime(m_composition->getBarEnd(m_currentBar));
- TQString label = TQString("%1 - %2 %3 %4").arg(strtoqstr(m_patternName))
- .arg(strtoqstr(m_sequenceName))
- .arg(i18n(" imported from Hydrogen ")).arg(strtoqstr(m_version));
+ TQString label = TQString("%1 - %2 %3 %4").tqarg(strtoqstr(m_patternName))
+ .tqarg(strtoqstr(m_sequenceName))
+ .tqarg(i18n(" imported from Hydrogen ")).tqarg(strtoqstr(m_version));
m_segment->setLabel(qstrtostr(label));
m_composition->addTrack(track);
diff --git a/src/document/io/HydrogenXMLHandler.h b/src/document/io/HydrogenXMLHandler.h
index e5ec4fe..f315824 100644
--- a/src/document/io/HydrogenXMLHandler.h
+++ b/src/document/io/HydrogenXMLHandler.h
@@ -45,7 +45,7 @@ class Segment;
class Composition;
-class HydrogenXMLHandler : public QXmlDefaultHandler
+class HydrogenXMLHandler : public TQXmlDefaultHandler
{
public:
HydrogenXMLHandler(Composition *comp,
diff --git a/src/document/io/LilyPondExporter.h b/src/document/io/LilyPondExporter.h
index 6ba3a21..a106243 100644
--- a/src/document/io/LilyPondExporter.h
+++ b/src/document/io/LilyPondExporter.h
@@ -87,8 +87,8 @@ public:
typedef std::multiset<Event*, Event::EventEndCmp> eventendlist;
public:
- LilyPondExporter(RosegardenGUIApp *parent, RosegardenGUIDoc *, std::string fileName);
- LilyPondExporter(NotationView *parent, RosegardenGUIDoc *, std::string fileName);
+ LilyPondExporter(RosegardenGUIApp *tqparent, RosegardenGUIDoc *, std::string fileName);
+ LilyPondExporter(NotationView *tqparent, RosegardenGUIDoc *, std::string fileName);
~LilyPondExporter();
bool write();
@@ -129,7 +129,7 @@ protected:
// compose an appropriate LilyPond representation for various Marks
std::string composeLilyMark(std::string eventMark, bool stemUp);
- // find/protect illegal characters in user-supplied strings
+ // tqfind/protect illegal characters in user-supplied strings
std::string protectIllegalChars(std::string inStr);
// return a string full of column tabs
diff --git a/src/document/io/MupExporter.cpp b/src/document/io/MupExporter.cpp
index 6207512..f17a8a3 100644
--- a/src/document/io/MupExporter.cpp
+++ b/src/document/io/MupExporter.cpp
@@ -45,10 +45,10 @@ namespace Rosegarden
{
using namespace BaseProperties;
-MupExporter::MupExporter(TQObject *parent,
+MupExporter::MupExporter(TQObject *tqparent,
Composition *composition,
string fileName) :
- ProgressReporter(parent, "mupExporter"),
+ ProgressReporter(tqparent, "mupExporter"),
m_composition(composition),
m_fileName(fileName)
{
diff --git a/src/document/io/MupExporter.h b/src/document/io/MupExporter.h
index 1ba8d5d..781080d 100644
--- a/src/document/io/MupExporter.h
+++ b/src/document/io/MupExporter.h
@@ -55,7 +55,7 @@ class Composition;
class MupExporter : public ProgressReporter
{
public:
- MupExporter(TQObject *parent, Composition *, std::string fileName);
+ MupExporter(TQObject *tqparent, Composition *, std::string fileName);
~MupExporter();
bool write();
diff --git a/src/document/io/MusicXmlExporter.cpp b/src/document/io/MusicXmlExporter.cpp
index 365a792..febd911 100644
--- a/src/document/io/MusicXmlExporter.cpp
+++ b/src/document/io/MusicXmlExporter.cpp
@@ -46,10 +46,10 @@ namespace Rosegarden
using namespace BaseProperties;
-MusicXmlExporter::MusicXmlExporter(TQObject *parent,
+MusicXmlExporter::MusicXmlExporter(TQObject *tqparent,
RosegardenGUIDoc *doc,
std::string fileName) :
- ProgressReporter(parent, "musicXmlExporter"),
+ ProgressReporter(tqparent, "musicXmlExporter"),
m_doc(doc),
m_fileName(fileName)
{
diff --git a/src/document/io/MusicXmlExporter.h b/src/document/io/MusicXmlExporter.h
index 7d8287d..f2da943 100644
--- a/src/document/io/MusicXmlExporter.h
+++ b/src/document/io/MusicXmlExporter.h
@@ -60,7 +60,7 @@ public:
typedef std::multiset<Event*, Event::EventCmp> eventstartlist;
typedef std::multiset<Event*, Event::EventEndCmp> eventendlist;
public:
- MusicXmlExporter(TQObject *parent, RosegardenGUIDoc *, std::string fileName);
+ MusicXmlExporter(TQObject *tqparent, RosegardenGUIDoc *, std::string fileName);
~MusicXmlExporter();
bool write();
diff --git a/src/document/io/RG21Loader.cpp b/src/document/io/RG21Loader.cpp
index d5df36d..78950de 100644
--- a/src/document/io/RG21Loader.cpp
+++ b/src/document/io/RG21Loader.cpp
@@ -58,8 +58,8 @@ using namespace Accidentals;
using namespace Marks;
RG21Loader::RG21Loader(Studio *studio,
- TQObject *parent, const char* name)
- : ProgressReporter(parent, name),
+ TQObject *tqparent, const char* name)
+ : ProgressReporter(tqparent, name),
m_stream(0),
m_studio(studio),
m_composition(0),
@@ -69,7 +69,7 @@ RG21Loader::RG21Loader(Studio *studio,
m_currentClef(Clef::Treble),
m_currentInstrumentId(MidiInstrumentBase),
m_inGroup(false),
- m_tieStatus(0),
+ m_tietqStatus(0),
m_nbStaves(0)
{}
@@ -106,8 +106,8 @@ bool RG21Loader::parseKey()
}
TQString keyName = TQString("%1 %2or")
- .arg(keyBase)
- .arg(m_tokens[3].lower());
+ .tqarg(keyBase)
+ .tqarg(m_tokens[3].lower());
m_currentKey = Rosegarden::Key(qstrtostr(keyName));
Event *keyEvent = m_currentKey.getAsEvent(m_currentSegmentTime);
@@ -173,10 +173,10 @@ bool RG21Loader::parseChordItem()
noteEvent->set
<Int>(PITCH, pitch);
- if (m_tieStatus == 1) {
+ if (m_tietqStatus == 1) {
noteEvent->set
<Bool>(TIED_FORWARD, true);
- } else if (m_tieStatus == 2) {
+ } else if (m_tietqStatus == 2) {
noteEvent->set
<Bool>(TIED_BACKWARD, true);
}
@@ -199,10 +199,10 @@ bool RG21Loader::parseChordItem()
}
m_currentSegmentTime += duration;
- if (m_tieStatus == 2)
- m_tieStatus = 0;
- else if (m_tieStatus == 1)
- m_tieStatus = 2;
+ if (m_tietqStatus == 2)
+ m_tietqStatus = 0;
+ else if (m_tietqStatus == 1)
+ m_tietqStatus = 2;
return true;
}
@@ -348,13 +348,13 @@ bool RG21Loader::parseIndicationStart()
if (indicationType == "tie") {
- if (m_tieStatus != 0) {
+ if (m_tietqStatus != 0) {
RG_DEBUG
<< "RG21Loader:: parseIndicationStart: WARNING: Found tie within "
<< "tie, ignoring" << endl;
return true;
}
- // m_tieStatus = 1;
+ // m_tietqStatus = 1;
Segment::iterator i = m_currentSegment->end();
if (i != m_currentSegment->begin()) {
@@ -368,7 +368,7 @@ bool RG21Loader::parseIndicationStart()
--i;
}
}
- m_tieStatus = 2;
+ m_tietqStatus = 2;
RG_DEBUG << "rg21io: Indication start: it's a tie" << endl;
@@ -484,7 +484,7 @@ void RG21Loader::closeGroup()
// To change the time of an event, we need to erase &
// re-insert it. But erasure will delete the event, and
- // if it's an indication event that will invalidate our
+ // if it's an indication event that will tqinvalidate our
// indicationsExtant entry. Hence this unpleasantness:
if ((*i)->isa(Indication::EventType)) {
diff --git a/src/document/io/RG21Loader.h b/src/document/io/RG21Loader.h
index 583367c..51e663b 100644
--- a/src/document/io/RG21Loader.h
+++ b/src/document/io/RG21Loader.h
@@ -58,7 +58,7 @@ class RG21Loader : public ProgressReporter
{
public:
RG21Loader(Studio *,
- TQObject *parent = 0, const char *name = 0);
+ TQObject *tqparent = 0, const char *name = 0);
~RG21Loader();
/**
@@ -145,7 +145,7 @@ protected:
int m_groupUntupledLength;
int m_groupUntupledCount;
- int m_tieStatus; // 0 -> none, 1 -> tie started, 2 -> seen one note
+ int m_tietqStatus; // 0 -> none, 1 -> tie started, 2 -> seen one note
TQString m_currentLine;
TQString m_currentStaffName;
diff --git a/src/document/io/LilyPondExporter.cpp b/src/document/io/LilyPondExporter.cpp
index cd29b60..f5e5ff9 100644
--- a/src/document/io/LilyPondExporter.cpp
+++ b/src/document/io/LilyPondExporter.cpp
@@ -85,26 +85,26 @@ using namespace BaseProperties;
const PropertyName LilyPondExporter::SKIP_PROPERTY
= "LilyPondExportSkipThisEvent";
-LilyPondExporter::LilyPondExporter(RosegardenGUIApp *parent,
+LilyPondExporter::LilyPondExporter(RosegardenGUIApp *tqparent,
RosegardenGUIDoc *doc,
std::string fileName) :
- ProgressReporter((TQObject *)parent, "lilypondExporter"),
+ ProgressReporter((TQObject *)tqparent, "lilypondExporter"),
m_doc(doc),
m_fileName(fileName),
m_lastClefFound(Clef::Treble)
{
m_composition = &m_doc->getComposition();
m_studio = &m_doc->getStudio();
- m_view = ((RosegardenGUIApp *)parent)->getView();
+ m_view = ((RosegardenGUIApp *)tqparent)->getView();
m_notationView = NULL;
readConfigVariables();
}
-LilyPondExporter::LilyPondExporter(NotationView *parent,
+LilyPondExporter::LilyPondExporter(NotationView *tqparent,
RosegardenGUIDoc *doc,
std::string fileName) :
- ProgressReporter((TQObject *)parent, "lilypondExporter"),
+ ProgressReporter((TQObject *)tqparent, "lilypondExporter"),
m_doc(doc),
m_fileName(fileName),
m_lastClefFound(Clef::Treble)
@@ -113,7 +113,7 @@ LilyPondExporter::LilyPondExporter(NotationView *parent,
m_composition = &m_doc->getComposition();
m_studio = &m_doc->getStudio();
m_view = NULL;
- m_notationView = ((NotationView *)parent);
+ m_notationView = ((NotationView *)tqparent);
readConfigVariables();
}
@@ -137,7 +137,7 @@ LilyPondExporter::readConfigVariables(void)
m_exportBeams = cfg->readBoolEntry("lilyexportbeamings", false);
m_exportStaffMerge = cfg->readBoolEntry("lilyexportstaffmerge", false);
m_exportStaffGroup = cfg->readBoolEntry("lilyexportstaffbrackets", true);
- m_lyricsHAlignment = cfg->readBoolEntry("lilylyricshalignment", LEFT_ALIGN);
+ m_lyricsHAlignment = cfg->readBoolEntry("lilylyricshtqalignment", LEFT_ALIGN);
m_languageLevel = cfg->readUnsignedNumEntry("lilylanguage", LILYPOND_VERSION_2_6);
m_exportMarkerMode = cfg->readUnsignedNumEntry("lilyexportmarkermode", EXPORT_NO_MARKERS );
@@ -351,15 +351,15 @@ LilyPondExporter::protectIllegalChars(std::string inStr)
TQString tmpStr = strtoqstr(inStr);
- tmpStr.replace(TQRegExp("&"), "\\&");
- tmpStr.replace(TQRegExp("\\^"), "\\^");
- tmpStr.replace(TQRegExp("%"), "\\%");
- tmpStr.replace(TQRegExp("<"), "\\<");
- tmpStr.replace(TQRegExp(">"), "\\>");
- tmpStr.replace(TQRegExp("\\["), "");
- tmpStr.replace(TQRegExp("\\]"), "");
- tmpStr.replace(TQRegExp("\\{"), "");
- tmpStr.replace(TQRegExp("\\}"), "");
+ tmpStr.tqreplace(TQRegExp("&"), "\\&");
+ tmpStr.tqreplace(TQRegExp("\\^"), "\\^");
+ tmpStr.tqreplace(TQRegExp("%"), "\\%");
+ tmpStr.tqreplace(TQRegExp("<"), "\\<");
+ tmpStr.tqreplace(TQRegExp(">"), "\\>");
+ tmpStr.tqreplace(TQRegExp("\\["), "");
+ tmpStr.tqreplace(TQRegExp("\\]"), "");
+ tmpStr.tqreplace(TQRegExp("\\{"), "");
+ tmpStr.tqreplace(TQRegExp("\\}"), "");
//
// LilyPond uses utf8 encoding.
@@ -389,11 +389,11 @@ LilyPondExporter::write()
TQString baseName = nfo.fileName();
// sed LilyPond-choking chars out of the filename proper
- bool illegalFilename = (baseName.contains(' ') || baseName.contains("\\"));
- baseName.replace(TQRegExp(" "), "");
- baseName.replace(TQRegExp("\\\\"), "");
- baseName.replace(TQRegExp("'"), "");
- baseName.replace(TQRegExp("\""), "");
+ bool illegalFilename = (baseName.tqcontains(' ') || baseName.tqcontains("\\"));
+ baseName.tqreplace(TQRegExp(" "), "");
+ baseName.tqreplace(TQRegExp("\\\\"), "");
+ baseName.tqreplace(TQRegExp("'"), "");
+ baseName.tqreplace(TQRegExp("\""), "");
// cat back together
tmpName = dirName + '/' + baseName;
@@ -402,7 +402,7 @@ LilyPondExporter::write()
CurrentProgressDialog::freeze();
int reply = KMessageBox::warningContinueCancel(
0, i18n("LilyPond does not allow spaces or backslashes in filenames.\n\n"
- "Would you like to use\n\n %1\n\n instead?").arg(baseName));
+ "Would you like to use\n\n %1\n\n instead?").tqarg(baseName));
if (reply != KMessageBox::Continue)
return false;
}
@@ -452,7 +452,7 @@ LilyPondExporter::write()
// LilyPond \header block
// set indention level to make future changes to horizontal layout less
// tedious, ++col to indent a new level, --col to de-indent
int col = 0;
@@ -583,7 +583,7 @@ LilyPondExporter::write()
// bind staffs with or without staff group bracket
str << indent(col) // indent
<< "<<" << " s4 " << ">>" << std::endl;
- str << indent(col) << "\\layout { }" << std::endl;
+ str << indent(col) << "\\tqlayout { }" << std::endl;
str << indent(--col) << "}" << std::endl;
return true;
}
@@ -1181,7 +1181,7 @@ LilyPondExporter::write()
text += " ";
TQString syllable(strtoqstr(ssyllable));
- syllable.replace(TQRegExp("\\s+"), "");
+ syllable.tqreplace(TQRegExp("\\s+"), "");
text += "\"" + syllable + "\"";
haveLyric = true;
} else if (verse > lastVerse) {
@@ -1190,8 +1190,8 @@ LilyPondExporter::write()
}
}
- text.replace( TQRegExp(" _+([^ ])") , " \\1" );
- text.replace( "\"_\"" , " " );
+ text.tqreplace( TQRegExp(" _+([^ ])") , " \\1" );
+ text.tqreplace( "\"_\"" , " " );
// Do not create empty context for lyrics.
// Does this save some vertical space, as was written
@@ -1202,17 +1202,17 @@ LilyPondExporter::write()
str << indent(col) << "\\lyricsto \"" << voiceNumber.str() << "\""
<< " \\new Lyrics \\lyricmode {" << std::endl;
if (m_lyricsHAlignment == RIGHT_ALIGN) {
- str << indent(++col) << "\\override LyricText #'self-alignment-X = #RIGHT"
+ str << indent(++col) << "\\override LyricText #'self-tqalignment-X = #RIGHT"
<< std::endl;
} else if (m_lyricsHAlignment == CENTER_ALIGN) {
- str << indent(++col) << "\\override LyricText #'self-alignment-X = #CENTER"
+ str << indent(++col) << "\\override LyricText #'self-tqalignment-X = #CENTER"
<< std::endl;
} else {
- str << indent(++col) << "\\override LyricText #'self-alignment-X = #LEFT"
+ str << indent(++col) << "\\override LyricText #'self-tqalignment-X = #LEFT"
<< std::endl;
}
str << indent(col) << "\\set ignoreMelismata = ##t" << std::endl;
- str << indent(col) << text.utf8() << " " << std::endl;
+ str << indent(col) << text.utf8().data() << " " << std::endl;
str << indent(col) << "\\unset ignoreMelismata" << std::endl;
str << indent(--col) << "} % Lyrics " << (currentVerse+1) << std::endl;
// close the Lyrics context
@@ -1253,8 +1253,8 @@ LilyPondExporter::write()
str << std::endl << indent(--col) << ">> % notes" << std::endl << std::endl; // indent-
// str << std::endl << indent(col) << ">> % global wrapper" << std::endl;
- // write \layout block
- str << indent(col) << "\\layout { }" << std::endl;
+ // write \tqlayout block
+ str << indent(col) << "\\tqlayout { }" << std::endl;
// write initial tempo in Midi block, if user wishes (added per user request...
// makes debugging the .ly file easier because fewer "noisy" errors are
@@ -1430,7 +1430,7 @@ LilyPondExporter::writeBar(Segment *s,
writtenDuration += note.getDuration();
durationRatio = writeSkip(timeSignature, 0, note.getDuration(), true, str);
durationRatioSum = fractionSum(durationRatioSum,durationRatio);
- // str << qstrtostr(TQString(" %{ %1/%2 %} ").arg(durationRatio.first).arg(durationRatio.second)); // DEBUG
+ // str << qstrtostr(TQString(" %{ %1/%2 %} ").tqarg(durationRatio.first).tqarg(durationRatio.second)); // DEBUG
}
timeT prevDuration = -1;
@@ -1496,7 +1496,7 @@ LilyPondExporter::writeBar(Segment *s,
groupId = -1;
groupType = "";
} else {
- startGroupBeamingsStr += TQString("\\times %1/%2 { ").arg(numerator).arg(denominator);
+ startGroupBeamingsStr += TQString("\\times %1/%2 { ").tqarg(numerator).tqarg(denominator);
tupletRatio = std::pair<int, int>(numerator, denominator);
// Require explicit beamed groups,
// fixes bug #1683205.
@@ -1534,7 +1534,7 @@ LilyPondExporter::writeBar(Segment *s,
// Test whether the next note is grace note or not.
// The start or end of beamed grouping should be put in proper places.
- str << endGroupBeamingsStr.utf8();
+ str << endGroupBeamingsStr.utf8().data();
if ((*i)->has(IS_GRACE_NOTE) && (*i)->get<Bool>(IS_GRACE_NOTE)) {
if (isGrace == 0) {
isGrace = 1;
@@ -1546,7 +1546,7 @@ LilyPondExporter::writeBar(Segment *s,
// str << "%{ grace ends %} "; // DEBUG
str << "} ";
}
- str << startGroupBeamingsStr.utf8();
+ str << startGroupBeamingsStr.utf8().data();
timeT soundingDuration = -1;
timeT duration = calculateDuration
@@ -1688,7 +1688,7 @@ LilyPondExporter::writeBar(Segment *s,
writtenDuration += soundingDuration;
std::pair<int,int> ratio = fractionProduct(durationRatio,tupletRatio);
durationRatioSum = fractionSum(durationRatioSum, ratio);
- // str << qstrtostr(TQString(" %{ %1/%2 * %3/%4 = %5/%6 %} ").arg(durationRatio.first).arg(durationRatio.second).arg(tupletRatio.first).arg(tupletRatio.second).arg(ratio.first).arg(ratio.second)); // DEBUG
+ // str << qstrtostr(TQString(" %{ %1/%2 * %3/%4 = %5/%6 %} ").tqarg(durationRatio.first).tqarg(durationRatio.second).tqarg(tupletRatio.first).tqarg(tupletRatio.second).tqarg(ratio.first).tqarg(ratio.second)); // DEBUG
std::vector<Mark> marks(chord.getMarksForChord());
// problem here: stem direction unavailable (it's a view-local property)
@@ -1869,7 +1869,7 @@ LilyPondExporter::writeBar(Segment *s,
writtenDuration += soundingDuration;
std::pair<int,int> ratio = fractionProduct(durationRatio,tupletRatio);
durationRatioSum = fractionSum(durationRatioSum, ratio);
- // str << qstrtostr(TQString(" %{ %1/%2 * %3/%4 = %5/%6 %} ").arg(durationRatio.first).arg(durationRatio.second).arg(tupletRatio.first).arg(tupletRatio.second).arg(ratio.first).arg(ratio.second)); // DEBUG
+ // str << qstrtostr(TQString(" %{ %1/%2 * %3/%4 = %5/%6 %} ").tqarg(durationRatio.first).tqarg(durationRatio.second).tqarg(tupletRatio.first).tqarg(tupletRatio.second).tqarg(ratio.first).tqarg(ratio.second)); // DEBUG
} else if ((*i)->isa(Clef::EventType)) {
try {
@@ -1992,16 +1992,16 @@ LilyPondExporter::writeBar(Segment *s,
str << "c:" << barreStart << "-" << barreEnd << "-" << barreFret << ";";
}
- if (fingering.getStringStatus( 6-stringNum ) == Guitar::Fingering::MUTED) {
+ if (fingering.getStringtqStatus( 6-stringNum ) == Guitar::Fingering::MUTED) {
str << stringNum << "-x;";
- } else if (fingering.getStringStatus( 6-stringNum ) == Guitar::Fingering::OPEN) {
+ } else if (fingering.getStringtqStatus( 6-stringNum ) == Guitar::Fingering::OPEN) {
str << stringNum << "-o;";
} else {
- int stringStatus = fingering.getStringStatus(6-stringNum);
+ int stringtqStatus = fingering.getStringtqStatus(6-stringNum);
if ((stringNum <= barreStart) && (stringNum >= barreEnd)) {
str << stringNum << "-" << barreFret << ";";
} else {
- str << stringNum << "-" << stringStatus << ";";
+ str << stringNum << "-" << stringtqStatus << ";";
}
}
}
@@ -452,7 +452,7 @@ LilyPondExporter::write()
// LilyPond \header block
- // set indention level to make future changes to horizontal layout less
+ // set indention level to make future changes to horizontal tqlayout less
// tedious, ++col to indent a new level, --col to de-indent
int col = 0;